# pymagic9

[![license](https://img.shields.io/badge/License-APACHE_2.0-yellow.svg)](http://www.apache.org/licenses/)
<a><img src="https://img.shields.io/badge/python-2.7 | 3.6 | 3.7 | 3.8 | 3.9 | 3.10 -orange.svg"></a>
![Tests](https://github.com/sammnnz/pymagic9/actions/workflows/tests.yml/badge.svg)
[![codecov](https://codecov.io/gh/sammnnz/pymagic9/branch/release-v0.1.0/graph/badge.svg?token=qQAiKKnctA)](https://codecov.io/gh/sammnnz/pymagic9)

## What is this?

This is a Python library based on calling the stack of frames at runtime and analyzing the code object of frames. 
For example, the `nameof` function is implemented here (as in C#).

## Install

`pip install pymagic9`

## Support

CPython `2.7`, `3.6`, `3.7`, `3.8`, `3.9`, `3.10` on `Windows`, `Ubuntu` and `MacOS` platform.

## Other

See [docs](https://sammnnz.github.io/pymagic9/) for more information.
